.. _veto:

Veto
====
Functions to manage the veto files that avoid multiple fatal-ending trials. Whenever a processing step ends with the
same error more than twice for a given sequence, that sequence is vetoed and manual intervention in needed to solve
the issue.

Reference/API
+++++++++++++

.. automodapi:: osa.veto